{$M 4096,0,0}
USES Dos, GUtils;

{$DEFINE Final}

TYPE
  ArchiveType = (ARJ,ZIP,UC2,LZH,RAR,HA,UNKNOWN);

CONST
  TempFileName = '$MBOMB$.$$$';
  ArchiveSize  : LongInt = 0;
  DeArchiveSize: LongInt = 0;
  Compressed   : Integer = 0;
  MinComp      : Integer = 56;

VAR
  FileName: STRING;
  PgmName : STRING;
  Options : STRING;
  Command : STRING;
  BatFile : STRING;
  ArcType : ArchiveType;


  PROCEDURE WriteInf(L,S:STRING; LA,SA:Byte);
  BEGIN
    Attribute(WhereX,WhereY,LA,Length(L));
    Attribute(WhereX+Length(L),WhereY,SA,Length(S));
    Writeln(L,S);
  END;


  PROCEDURE Error(Msg:STRING);
  BEGIN
    WriteInf('ERROR: ',Msg,$04,$0C);
    Halt(1)
  END;


PROCEDURE CheckIt;
VAR T:Text; S:STRING; Cnt:Byte;
BEGIN
  Assign(T, TempFileName);
  {$I-}
   Reset(T);
  {$I+}
  IF IOResult <> 0 THEN Error('Can''t open '+TempFileName);
  Cnt := 0;
  WHILE NOT Eof(T) DO
  BEGIN
    ReadLn(T,S);
    CASE ArcType OF
      ARJ: IF Pos('files',S) <> 0 THEN
           BEGIN
             ArchiveSize   := StrToInt(Copy(S,25,10));
             DeArchiveSize := StrToInt(Copy(S,14,10));
             Break;
           END;
      ZIP: IF Pos(' ------          ------',S) <> 0 THEN
           BEGIN
             ReadLn(T,S);
             ArchiveSize   := StrToInt(Copy(S,15,10));
             DeArchiveSize := StrToInt(Copy(S,1,10));
             Break;
           END;
      LZH: IF Pos('files',S) <> 0 THEN
           BEGIN
             ArchiveSize   := StrToInt(Copy(S,26,10));
             DeArchiveSize := StrToInt(Copy(S,15,10));
             Break;
           END;
      RAR: IF Pos('---------------',S) <> 0 THEN
           BEGIN
             IF Cnt = 0 THEN BEGIN Inc(Cnt); Continue; END;
             ReadLn(T,S);
             ArchiveSize   := StrToInt(Copy(S,23,9));
             DeArchiveSize := StrToInt(Copy(S,12,11));
             Break;
           END;
    END;
  END;
  Close(T);
  Compressed := RetPercent(100,DeArchiveSize,ArchiveSize);
END;


FUNCTION GetArchiveType(Name:STRING): Archivetype;
VAR F:FILE; Buf:Word; StrBuf:STRING[3];
BEGIN
  GetArchiveType := UNKNOWN;
  Assign (F,Name);
  FileMode := 0;
  {$I-}
    Reset(F,1);
  {$I+}
  IF IOResult <> 0 THEN Error('Can''t open '+Name);
  BlockRead(F,Buf,2);
  CASE Buf OF
    $EA60: GetArchiveType := ARJ;
    $4B50: GetArchiveType := ZIP;
    $6152: GetArchiveType := RAR;
    $4355: GetArchiveType := UC2;
    $4148: GetArchiveType := HA;
   ELSE
   BEGIN
     BlockRead(F,StrBuf[1],3);
     StrBuf[0] := #3;
     IF StrBuf = '-lh'
      THEN GetArchiveType := LZH;
   END;
  END;
  Close(F);
END;




{---------------------------------------------------------------------------}
BEGIN
  ClrScr(7);
  Writeln(#13#10#13#10);
  FastWrite(1,1,$D,'       ANTI MAIL BOMB v1.0 ');
  FastWrite(1,2,$5,'Copyright (C) 1997 by The GodFather');

  {$IFDEF Final}
  IF (ParamStr(1) = '/?') OR (ParamCount < 3) THEN
  BEGIN
    WriteInf('  Usage: ','ANTI_MB [arc_name] [min_compression] [.BAT to run]',$07,$0F);
    Halt;
  END;
  FileName := AdjCase (Upper,ParamStr(1) );
  MinComp  := StrToInt(ParamStr(2)       );
  BatFile  := AdjCase (Upper,ParamStr(3) );
  {$ELSE}
  FileName := 'TEST.ARJ';
  BatFile  := 'AMB!.BAT';
  {$ENDIF}

  WriteInf('       Using file: ',FileName,$09,$0B);
  ArcType  := GetArchiveType(FileName);
  WriteInf(' Min. compression: ',IntToStr(MinComp)+'%',$09,$0B);
  WriteInf('         BAT file: ',BatFile,$09,$0B);
  Writeln('          -----');
  WriteInf('        File type: ','                  ',$0E,$0F);
  PosCursor(20,WhereY-1);
  CASE ArcType OF
    ARJ     : BEGIN Writeln('ARJ'); PgmName := 'ARJ.EXE';   Options := ' l '; END;
    ZIP     : BEGIN Writeln('ZIP'); PgmName := 'PKZIP.EXE'; Options := ' -v '; END;
    LZH     : BEGIN Writeln('LZH'); PgmName := 'LHA.EXE';   Options := ' l '; END;
    RAR     : BEGIN Writeln('RAR'); PgmName := 'RAR.EXE';   Options := ' l -c- -av- '; END;
    ELSE      BEGIN
                Writeln(FileName,'UNKNOWN');
                Error('The supported archives are: ARJ, ZIP, LZH & RAR');
                Halt;
              END;
  END;
  Command := FSearch(PgmName,GetEnv('PATH'));
  IF Command <> ''
   THEN BEGIN
          Command := FExpand(Command);
          RunAnything(Command+Options+FileName+' > $MBOMB$.$$$');
          CheckIt;
          Writeln('          -----');
          WriteInf('      ArchiveSize: ',IntToStr(ArchiveSize),$02,$0A);
          WriteInf('       Total size: ',IntToStr(DeArchiveSize),$02,$0A);
          WriteInf('      Compression: ',IntToStr(Compressed)+'%',$02,$0A);
          Writeln;
          IF Compressed < MinComp THEN
          BEGIN
            WriteInf('NOT ACCEPTIBLE COMPRESSION RATIO!',' Starting '+BatFile,$04,$0C);
            Writeln;
            RunAnything(BatFile);
          END ELSE WriteInf('EVERYTHING IS OK!',#13#10,$0F,$07);
        END
   ELSE Error('Can''t find '+PgmName+' in PATH');
   DeleteFile(TempFileName);
END.